@@ -1,7 +1,7 @@
 from .bot import Bot
 from .event import Event, MessageEvent, GroupMessage, FriendMessage, TempMessage # noqa
 from .adapter import Adapter
-from .message import MessageChain, MessageSegment
+from .message import MessageChain, MessageSegment, MessageType
 from .permission import (
     UserPermission,
     GROUP_MEMBER,
@@ -13,7 +13,7 @@ from .permission import (
 )
 
 __all__ = [
-    "Bot", "Event", "Adapter", "MessageChain", "MessageSegment",
+    "Bot", "Event", "Adapter", "MessageChain", "MessageSegment", "MessageType"
     "MessageEvent", "GroupMessage", "FriendMessage", "TempMessage",
     "UserPermission", "GROUP_MEMBER", "GROUP_ADMIN", "GROUP_ADMINS",
     "GROUP_OWNER", "GROUP_OWNER_SUPERUSER", "SUPERUSER"
